@@ -79,11 +79,12 @@ def to_constraints(requirements: str) -> str:
     """Convert requirements to constraints."""
 
     def _to_constraints() -> Iterator[str]:
-        lines = requirements.strip().splitlines()
+        lines = requirements.splitlines()
         for line, requirement in enumerate(lines, start=1):
-            constraint = to_constraint(requirement, line)
-            if constraint is not None:
-                yield constraint
+            if requirement.strip():
+                constraint = to_constraint(requirement, line)
+                if constraint is not None:
+                    yield constraint
 
     return "\n".join(_to_constraints())
 
@@ -196,8 +197,11 @@ class _PoetrySession:
         Returns:
             The path to the requirements file.
         """
-        tmpdir = Path(self.session.virtualenv.location) / "tmp"
-        tmpdir.mkdir(exist_ok=True)
+        # Avoid ``session.virtualenv.location`` because PassthroughEnv does not
+        # have it. We'll just create a fake virtualenv directory in this case.
+
+        tmpdir = Path(self.session._runner.envdir) / "tmp"
+        tmpdir.mkdir(exist_ok=True, parents=True)
 
         path = tmpdir / "requirements.txt"
         hashfile = tmpdir / f"{path.name}.hash"
